Documentation
¶
Index ¶
Constants ¶
const ( QueryBlock = "query" CheckBlock = "check" DashboardBlock = "dashboard" DatabaseBlock = "database" GeneralBlock = "general" PluginBlock = "plugin" )
hcl options block types
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CanSetTiming ¶ added in v1.6.0
type CanSetTiming interface {
SetTiming(flag string, r hcl.Range) hcl.Diagnostics
}
type Check ¶
type Check struct {
Output *string `hcl:"output" cty:"check_output"`
Separator *string `hcl:"separator" cty:"check_separator"`
Header *bool `hcl:"header" cty:"check_header"`
Timing *bool `hcl:"timing" cty:"check_timing"`
}
Check options are deprecated and removed. They are kept here for compatibility with old configurations.
func (*Check) Merge ¶
Merge :: merge other options over the the top of this options object i.e. if a property is set in otherOptions, it takes precedence
func (*Check) SetBaseProperties ¶
type Dashboard ¶ added in v1.6.0
type Dashboard struct {
// workspace profile
Browser *bool `hcl:"browser" cty:"profile_dashboard_browser"`
}
Dashboard options are deprecated and removed. They are kept here for compatibility with old configurations.
func (*Dashboard) ConfigMap ¶ added in v1.6.0
ConfigMap creates a config map that can be merged with viper
func (*Dashboard) Merge ¶ added in v1.6.0
Merge :: merge other options over the top of this options object i.e. if a property is set in otherOptions, it takes precedence
func (*Dashboard) SetBaseProperties ¶ added in v1.6.0
type Query ¶
type Query struct {
Output *string `hcl:"output" cty:"query_output"`
Separator *string `hcl:"separator" cty:"query_separator"`
Header *bool `hcl:"header" cty:"query_header"`
Multi *bool `hcl:"multi" cty:"query_multi"`
Timing *string `hcl:"timing" cty:"query_timing"` // parsed manually
AutoComplete *bool `hcl:"autocomplete" cty:"query_autocomplete"`
}
General
func (*Query) Merge ¶
Merge :: merge other options over the the top of this options object i.e. if a property is set in otherOptions, it takes precedence
func (*Query) SetBaseProperties ¶
type Server ¶
TODO KAI this is Flowpipe specific - should it be named as such
func (*Server) Merge ¶
Merge merges other options over the top of this options object i.e. if a property is set in otherOptions, it takes precedence
func (*Server) SetBaseProperties ¶
TODO KAI what is the difference between merge and SetBaseProperties